# Colorr Package

This is a package to do with colors like picking them or  
storing colors you come across that you can then retreive later

You can email me here: [My email](mailto:spareafro@post.com)
You can also check out my other package, Timerr: [timerr](https://github.com/ItzAfroBoy/timerr)